==> aroundme_0_3_3.tar: aroundme_0_3_3/www/aroundme_0_3_3/template/am_default/my_menu.inc.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table border="0" cellspacing="0" cellpadding="4" width="100%">
	<tr>
		<td class="txt_title">
			<?php echo $lang['section_menu'];?><br />
			<hr />
		</td>
	</tr>
	<tr>
		<td valign="top" class="txt_sub_menu_on">
			<?php
			if ($page_name_short == "my_overview") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_overview'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_overview.php" class="txt_sub_menu"><?php echo $lang['menu_overview'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "my_profile") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_profile'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_profile.php" class="txt_sub_menu"><?php echo $lang['menu_profile'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "my_favourites") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_favourites'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_favourites.php" class="txt_sub_menu"><?php echo $lang['menu_favourites'];?></a><br />
			<?php }?>



			<?php
			if ($page_name_short == "my_guestbook") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_guestbook'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_guestbook.php" class="txt_sub_menu"><?php echo $lang['menu_guestbook'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "my_blog") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_blog'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_blog.php" class="txt_sub_menu"><?php echo $lang['menu_blog'];?></a><br />
			<?php }?>

			<?php
			if ($page_name_short == "my_library") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_library'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_library.php" class="txt_sub_menu"><?php echo $lang['menu_library'];?></a><br />
			<?php }?>

			<?php
			if ($page_name_short == "my_publishing") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_publishing'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_publishing.php" class="txt_sub_menu"><?php echo $lang['menu_publishing'];?></a><br />
			<?php }?>

			<?php
			if ($page_name_short == "my_polls") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_polls'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_polls.php" class="txt_sub_menu"><?php echo $lang['menu_polls'];?></a><br />
			<?php }?>

			<?php
			if ($page_name_short == "my_images") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_images'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_images.php" class="txt_sub_menu"><?php echo $lang['menu_images'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "my_shoutbox") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_shout'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_shoutbox.php" class="txt_sub_menu"><?php echo $lang['menu_shout'];?></a><br />
			<?php }?>

		</td>
	</tr>
</table>

==> aroundme-0_4_0.tar: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/my_menu.inc.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table border="0" cellspacing="0" cellpadding="4" width="100%">
	<tr>
		<td class="txt_title">
			<?php echo $lang['section_menu'];?><br />
			<hr />
		</td>
	</tr>
	<tr>
		<td valign="top" class="txt_sub_menu_on">
			<?php
			if ($page_name_short == "my_overview") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_overview'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_overview.php" class="txt_sub_menu"><?php echo $lang['menu_overview'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "my_membership") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_membership'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_membership.php" class="txt_sub_menu"><?php echo $lang['menu_membership'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "my_profile") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_profile'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_profile.php" class="txt_sub_menu"><?php echo $lang['menu_profile'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "my_bookmarks") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_bookmarks'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_bookmarks.php" class="txt_sub_menu"><?php echo $lang['menu_bookmarks'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "my_blog") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_blog'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_blog.php" class="txt_sub_menu"><?php echo $lang['menu_blog'];?></a><br />
			<?php }?>

			<?php
			if ($page_name_short == "my_library") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_library'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_library.php" class="txt_sub_menu"><?php echo $lang['menu_library'];?></a><br />
			<?php }?>

			<?php
			if ($page_name_short == "my_publishing") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_publishing'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_publishing.php" class="txt_sub_menu"><?php echo $lang['menu_publishing'];?></a><br />
			<?php }?>

			<?php
			if ($page_name_short == "my_files") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_files'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_files.php" class="txt_sub_menu"><?php echo $lang['menu_files'];?></a><br />
			<?php }?>


			<?php
			if ($page_name_short == "my_shoutbox") {
			?>
			<span class="txt_sub_menu_on"><?php echo $lang['menu_shout'];?></span><br />
			<?php
			} else {
			?>
			<a href="my_shoutbox.php" class="txt_sub_menu"><?php echo $lang['menu_shout'];?></a><br />
			<?php }?>

		</td>
	</tr>
</table>
